]> git.ipfire.org Git - ipfire-2.x.git/blobdiff - make.sh
Set version to "2.7".
[ipfire-2.x.git] / make.sh
diff --git a/make.sh b/make.sh
index 2312eeb8b84a3b943e6acf5a1f31430775817852..9eca589d5c11563f58cd57ee8767ff19eaf20558 100755 (executable)
--- a/make.sh
+++ b/make.sh
 ############################################################################
 #
 
-NAME="IPFire"                                                                          # Software name
-SNAME="ipfire"                                                                 # Short name
-VERSION="2.5"
-CORE="32"
-GIT_BRANCH=master:master                                                                               # Version number
-SLOGAN="www.ipfire.org"                                        # Software slogan
-CONFIG_ROOT=/var/ipfire                                        # Configuration rootdir
-NICE=10                                                                                                        # Nice level
-MAX_RETRIES=1                                                                          # prefetch/check loop
+NAME="IPFire"                                                  # Software name
+SNAME="ipfire"                                                 # Short name
+VERSION="2.7"                                                  # Version number
+CORE="38"                                                      # Core Level (Filename)
+PAKFIRE_CORE="38"                                              # Core Level (PAKFIRE)
+GIT_BRANCH=`git status | head -n1 | cut -d" " -f4`             # Git Branch
+SLOGAN="www.ipfire.org"                                                # Software slogan
+CONFIG_ROOT=/var/ipfire                                                # Configuration rootdir
+NICE=10                                                                # Nice level
+MAX_RETRIES=1                                                  # prefetch/check loop
+BUILD_IMAGES=1                                                 # Build USB, Flash and Xen Images
 KVER=`grep --max-count=1 VER lfs/linux | awk '{ print $3 }'`
 MACHINE=`uname -m`
-GIT_TAG=$(git tag | tail -1)
-TOOLCHAINVER=1
+GIT_TAG=$(git tag | tail -1)                                   # Git Tag
+GIT_LASTCOMMIT=$(git log | head -n1 | cut -d" " -f2 |head -c8) # Last commit
+TOOLCHAINVER=2
 IPFVER="full"                          # Which versions should be compiled? (full|devel)
 
 # Debian specific settings
@@ -338,28 +341,34 @@ buildipfire() {
   ipfiremake pptp
   ipfiremake unzip
   ipfiremake which
+  ipfiremake xz
+  ipfiremake linux-firmware
   ipfiremake linux                     XEN=1
-  ipfiremake atl2                      XEN=1
-  ipfiremake hso                       XEN=1
-  ipfiremake e1000e                    XEN=1
   ipfiremake kqemu                     XEN=1
   ipfiremake v4l-dvb                   XEN=1
   ipfiremake madwifi                   XEN=1
-#  ipfiremake alsa                     XEN=1 KMOD=1
-  ipfiremake openswan                  XEN=1 KMOD=1
-  ipfiremake mISDN                     XEN=1
+  ipfiremake dahdi                     XEN=1 KMOD=1
+  ipfiremake cryptodev                 XEN=1
   ipfiremake compat-wireless           XEN=1
+  ipfiremake r8169                     XEN=1
+  ipfiremake r8168                     XEN=1
+  ipfiremake r8101                     XEN=1
+  ipfiremake e1000                     XEN=1
+  ipfiremake e1000e                    XEN=1
   ipfiremake linux
-  ipfiremake atl2
-  ipfiremake hso
-  ipfiremake e1000e
   ipfiremake kqemu
+  ipfiremake kvm-kmod
   ipfiremake v4l-dvb
   ipfiremake madwifi
   ipfiremake alsa                      KMOD=1
-  ipfiremake openswan                  KMOD=1
-  ipfiremake mISDN
+  ipfiremake dahdi                     KMOD=1
+  ipfiremake cryptodev
   ipfiremake compat-wireless
+  ipfiremake r8169
+  ipfiremake r8168
+  ipfiremake r8101
+  ipfiremake e1000
+  ipfiremake e1000e
   ipfiremake pkg-config
   ipfiremake linux-atm
   ipfiremake cpio
@@ -524,8 +533,6 @@ buildipfire() {
   ipfiremake xvid
   ipfiremake libmpeg2
   ipfiremake cmake
-  ipfiremake libpri
-  ipfiremake asterisk
   ipfiremake gnump3d
   ipfiremake libsigc++
   ipfiremake applejuice
@@ -545,21 +552,22 @@ buildipfire() {
   ipfiremake tripwire
   ipfiremake sysstat
   ipfiremake vsftpd
-  ipfiremake openswan
+  ipfiremake strongswan
   ipfiremake lsof
   ipfiremake centerim
   ipfiremake br2684ctl
   ipfiremake pcmciautils
   ipfiremake lm_sensors
+  ipfiremake liboping
   ipfiremake collectd
   ipfiremake lcd4linux
-  ipfiremake tcptrack
   ipfiremake teamspeak
   ipfiremake elinks
   ipfiremake igmpproxy
   ipfiremake fbset
   ipfiremake sdl
   ipfiremake qemu
+  ipfiremake qemu-kqemu
   ipfiremake sane
   ipfiremake netpbm
   ipfiremake phpSANE
@@ -570,6 +578,7 @@ buildipfire() {
   ipfiremake freefont
   ipfiremake directfb
   ipfiremake dfb++
+  ipfiremake faad2
   ipfiremake ffmpeg
   ipfiremake videolan
   ipfiremake vdr
@@ -577,11 +586,11 @@ buildipfire() {
   ipfiremake icecast
   ipfiremake icegenerator
   ipfiremake mpd
+  ipfiremake libmpdclient
   ipfiremake mpc
   ipfiremake git
   ipfiremake squidclamav
   ipfiremake bc
-  ipfiremake esniper
   ipfiremake vnstat
   ipfiremake vnstati
   ipfiremake iw
@@ -599,7 +608,6 @@ buildipfire() {
   ipfiremake netcat
   ipfiremake 7zip
   ipfiremake lynis
-  #ipfiremake cryptsetup
   ipfiremake splix
   ipfiremake streamripper
   ipfiremake sshfs
@@ -609,13 +617,10 @@ buildipfire() {
   ipfiremake sslh
   ipfiremake perl-gettext
   ipfiremake vdradmin
-#  ipfiremake x11libs
-#  ipfiremake xen
   ipfiremake miau
   ipfiremake netsnmpd
   ipfiremake perl-DBI
   ipfiremake perl-DBD-mysql
-  ipfiremake lcr
   ipfiremake cacti
   ipfiremake icecc
   ipfiremake open-vm-tools
@@ -624,6 +629,16 @@ buildipfire() {
   ipfiremake motion
   ipfiremake joe
   ipfiremake nut
+  ipfiremake watchdog
+  ipfiremake libpri
+  ipfiremake dahdi
+  ipfiremake asterisk
+  ipfiremake lcr
+  ipfiremake usb_modeswitch
+  ipfiremake zerofree
+  ipfiremake mdadm
+  ipfiremake eject
+  ipfiremake pound
   echo Build on $HOSTNAME > $BASEDIR/build/var/ipfire/firebuild
   cat /proc/version >> $BASEDIR/build/var/ipfire/firebuild
   echo >> $BASEDIR/build/var/ipfire/firebuild
@@ -632,8 +647,12 @@ buildipfire() {
   git status >> $BASEDIR/build/var/ipfire/firebuild
   echo >> $BASEDIR/build/var/ipfire/firebuild
   cat /proc/cpuinfo >> $BASEDIR/build/var/ipfire/firebuild
-  echo $CORE > $BASEDIR/build/opt/pakfire/db/core/mine
-  echo $NAME $VERSION - Core$CORE > $BASEDIR/build/etc/system-release
+  echo $PAKFIRE_CORE > $BASEDIR/build/opt/pakfire/db/core/mine
+  if [ "$GIT_BRANCH" = "master" ]; then
+       echo "$NAME $VERSION - (Development Build: $GIT_LASTCOMMIT)" > $BASEDIR/build/etc/system-release
+  else
+       echo "$NAME $VERSION - $GIT_BRANCH" > $BASEDIR/build/etc/system-release
+  fi
 }
 
 buildinstaller() {
@@ -705,7 +724,7 @@ buildpackages() {
        ipfiremake cdrom ED=$IPFVER
 
   # Check if there is a loop device for building in virtual environments
-  if [ -e /dev/loop/0 ] || [ -e /dev/loop0 ]; then
+  if [ $BUILD_IMAGES == 1 ] &&  ([ -e /dev/loop/0 ] || [ -e /dev/loop0 ]); then
        ipfiremake usb-stick ED=$IPFVER
        ipfiremake flash-images ED=$IPFVER
   fi
@@ -715,7 +734,7 @@ buildpackages() {
   ipfirepackages
 
   # Check if there is a loop device for building in virtual environments
-  if [ -e /dev/loop/0 ] || [ -e /dev/loop0 ]; then
+  if [ $BUILD_IMAGES == 1 ] && ([ -e /dev/loop/0 ] || [ -e /dev/loop0 ]); then
         cp -f $BASEDIR/packages/linux-xen-*.ipfire $LFS/install/packages/
         cp -f $BASEDIR/packages/meta-linux-xen $LFS/install/packages/
        ipfiremake xen-image ED=$IPFVER
@@ -893,7 +912,7 @@ toolchain)
        buildtoolchain
        BUILDMACHINE=`uname -m`
        echo "`date -u '+%b %e %T'`: Create toolchain tar.gz for $BUILDMACHINE" | tee -a $LOGFILE
-       test -d $BASEDIR/cache/toolchains || mkdir $BASEDIR/cache/toolchains
+       test -d $BASEDIR/cache/toolchains || mkdir -p $BASEDIR/cache/toolchains
        cd $BASEDIR && tar -zc --exclude='log/_build.*.log' -f cache/toolchains/$SNAME-$VERSION-toolchain-$TOOLCHAINVER-$BUILDMACHINE.tar.gz \
                build/{bin,etc,usr/bin,usr/local} \
                build/tools/{bin,etc,*-linux-gnu,include,lib,libexec,sbin,share,var} \
@@ -908,7 +927,7 @@ gettoolchain)
        PACKAGE=$SNAME-$VERSION-toolchain-$TOOLCHAINVER-$BUILDMACHINE
        if [ ! -f $BASEDIR/cache/toolchains/$PACKAGE.tar.gz ]; then
                URL_TOOLCHAIN=`grep URL_TOOLCHAIN lfs/Config | awk '{ print $3 }'`
-               test -d $BASEDIR/cache/toolchains || mkdir $BASEDIR/cache/toolchains
+               test -d $BASEDIR/cache/toolchains || mkdir -p $BASEDIR/cache/toolchains
                echo "`date -u '+%b %e %T'`: Load toolchain tar.gz for $BUILDMACHINE" | tee -a $LOGFILE
                cd $BASEDIR/cache/toolchains
                wget -U "IPFireSourceGrabber/2.x" $URL_TOOLCHAIN/$PACKAGE.tar.gz $URL_TOOLCHAIN/$PACKAGE.md5 >& /dev/null
@@ -979,7 +998,7 @@ git)
                [ -z $GIT_USER ] && exiterror "You have to setup GIT_USER first."
                        GIT_URL="ssh://${GIT_USER}@git.ipfire.org/pub/git/ipfire-2.x"
                        
-               git push ${GIT_URL} ${GIT_BRANCH} $3
+               git push ${GIT_URL} $3
                ;;
          log)
                [ -z $GIT_TAG ]  || LAST_TAG=$GIT_TAG